@@ -3,9 +3,6 @@
 require 'simplecov'
 SimpleCov.start
 
-require 'codecov'
-SimpleCov.formatter = SimpleCov::Formatter::Codecov
-
 require 'ddmetrics'
 
 require 'fuubar'
